ag_train: Switch a layer or sequential model to training mode

View source: R/ag_layers.R

ag_trainR Documentation

Switch a layer or sequential model to training mode

Description

Switch a layer or sequential model to training mode

Usage

ag_train(model)

Arguments

model

An ag_sequential, ag_batch_norm, or ag_dropout layer

Value

The model/layer (invisibly)


ggmlR documentation built on July 14, 2026, 1:08 a.m.