| ggml_backend_sched_get_n_copies | R Documentation |
Returns the number of tensor copies made in the last computed graph. Copies occur when data needs to be transferred between backends.
ggml_backend_sched_get_n_copies(sched)
sched |
Scheduler pointer |
Integer count of copies
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.