ggml_graph_reset: Reset Graph (for backpropagation)

View source: R/graph.R

ggml_graph_resetR Documentation

Reset Graph (for backpropagation)

Description

Resets the computation graph for a new backward pass. NOTE: This function requires the graph to have gradients allocated (used for training/backpropagation). For inference-only graphs, this function will cause an error.

Usage

ggml_graph_reset(graph)

Arguments

graph

Graph object with gradients allocated

Value

No return value, called for side effects


ggmlR documentation built on July 14, 2026, 1:08 a.m.