| ggml_graph_view | R Documentation |
Creates a view of a portion of a computation graph, containing nodes from index i0 to i1 (exclusive). The view shares the underlying nodes but does not include leaf tensors or gradients.
ggml_graph_view(graph, i0, i1)
graph |
External pointer to computation graph |
i0 |
Start index (0-based, inclusive) |
i1 |
End index (exclusive) |
External pointer to graph view
Other graph:
ggml_op_can_inplace()
ctx <- ggml_init(16 * 1024 * 1024)
a <- ggml_new_tensor_1d(ctx, GGML_TYPE_F32, 10)
b <- ggml_relu(ctx, a)
graph <- ggml_build_forward_expand(ctx, b)
n_nodes <- ggml_graph_n_nodes(graph)
view <- ggml_graph_view(graph, 0, n_nodes)
ggml_free(ctx)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.