ggml_set_param: Set Tensor as Trainable Parameter

View source: R/operations.R

ggml_set_paramR Documentation

Set Tensor as Trainable Parameter

Description

Marks a tensor as a trainable parameter for backpropagation. The optimizer will compute gradients for this tensor during training.

Usage

ggml_set_param(tensor)

Arguments

tensor

Tensor pointer

Value

The tensor (for chaining)


ggmlR documentation built on July 14, 2026, 1:08 a.m.