ggml_soft_max_ext_back_inplace: Extended Softmax Backward Inplace (Graph)

View source: R/operations.R

ggml_soft_max_ext_back_inplaceR Documentation

Extended Softmax Backward Inplace (Graph)

Description

Creates a graph node for the backward pass of extended softmax, modifying in place.

Usage

ggml_soft_max_ext_back_inplace(ctx, a, b, scale = 1, max_bias = 0)

Arguments

ctx

GGML context

a

Gradient tensor from upstream

b

Softmax output from forward pass

scale

Scaling factor used in forward pass

max_bias

Maximum ALiBi bias used in forward pass

Value

View of input tensor with gradient computed in place

See Also

Other softmax: ggml_soft_max_ext_inplace()


ggmlR documentation built on July 14, 2026, 1:08 a.m.