nn_build_functional_node: Build a single ggml tensor for one functional node

View source: R/nn_functional.R

nn_build_functional_nodeR Documentation

Build a single ggml tensor for one functional node

Description

Build a single ggml tensor for one functional node

Usage

nn_build_functional_node(
  node,
  built_tensors,
  built_shapes,
  ctx_weights,
  ctx_compute,
  batch_size,
  training = FALSE,
  reuse_weights = NULL
)

Arguments

reuse_weights

Named list of pre-allocated weight tensors to reuse (for shared layers – second+ application of a named layer). When not NULL the function uses these tensors instead of allocating new ones.

Value

A ggml_tensor produced by building the given functional graph node.


ggmlR documentation built on July 14, 2026, 1:08 a.m.