nn_functional_output_shape: Infer output shape of a functional node given its parent...

View source: R/nn_functional.R

nn_functional_output_shapeR Documentation

Infer output shape of a functional node given its parent shapes

Description

Infer output shape of a functional node given its parent shapes

Usage

nn_functional_output_shape(node, parent_shapes)

Value

An integer vector with the inferred output shape (excluding the batch dimension).


ggmlR documentation built on July 14, 2026, 1:08 a.m.