| onnx_inputs | R Documentation |
Returns the names and shapes of model inputs (excluding weight
initializers). Use this to know what to pass to onnx_run().
onnx_inputs(model)
model |
An |
A named list where names are input tensor names and values are integer vectors of dimension sizes (-1 for dynamic dimensions).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.