| ag_softmax_cross_entropy_loss | R Documentation |
Combines softmax and CE in one op using the fused gradient (p - y) / n.
More numerically stable than chaining ag_softmax + ag_cross_entropy_loss.
Use this when your last layer outputs raw logits.
ag_softmax_cross_entropy_loss(logits, target)
logits |
ag_tensor [classes, batch_size] raw (pre-softmax) scores |
target |
matrix [classes, batch_size] one-hot labels |
scalar ag_tensor
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.