| ag_tensor | R Documentation |
ag_tensor is backed by an R environment so all references to the same tensor see updates (like PyTorch tensors).
ag_tensor(
data,
device = .ag_device_state$device,
dtype = .ag_device_state$dtype
)
data |
Numeric matrix or vector |
device |
|
dtype |
Floating-point precision: |
An ag_tensor object (environment)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.