Learn R Programming

ggmlR (version 0.6.1)

ag_train: Switch a layer or sequential model to training mode

Description

Switch a layer or sequential model to training mode

Usage

ag_train(model)

Value

The model/layer (invisibly)

Arguments

model

An ag_sequential, ag_batch_norm, or ag_dropout layer