| ggml_diag_mask_zero | R Documentation |
Creates a graph node that sets elements above the diagonal to 0. Alternative to -Inf masking for certain use cases.
ggml_diag_mask_zero(ctx, a, n_past)
ctx |
GGML context |
a |
Input tensor |
n_past |
Number of past tokens |
Tensor with same shape as input, elements above diagonal set to 0
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.