| ggml_graph_reset | R Documentation |
Resets the computation graph for a new backward pass. NOTE: This function requires the graph to have gradients allocated (used for training/backpropagation). For inference-only graphs, this function will cause an error.
ggml_graph_reset(graph)
graph |
Graph object with gradients allocated |
No return value, called for side effects
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.