Learn R Programming

ggmlR (version 0.6.1)

ggml_graph_reset: Reset Graph (for backpropagation)

Description

Resets the computation graph for a new backward pass. NOTE: This function requires the graph to have gradients allocated (used for training/backpropagation). For inference-only graphs, this function will cause an error.

Usage

ggml_graph_reset(graph)

Value

No return value, called for side effects

Arguments

graph

Graph object with gradients allocated