powered by
Resets the computation graph for a new backward pass. NOTE: This function requires the graph to have gradients allocated (used for training/backpropagation). For inference-only graphs, this function will cause an error.
ggml_graph_reset(graph)
No return value, called for side effects
Graph object with gradients allocated