| ggml_save_model | R Documentation |
Saves both the architecture and trained weights of a model to an RDS file.
Unlike ggml_save_weights(), which requires the model to be manually
reconstructed before loading, ggml_save_model() saves everything
needed to restore the model with a single call to ggml_load_model().
ggml_save_model(model, path)
model |
A trained |
path |
File path (typically |
The model (invisibly).
ggml_sequential_model — input shape, layer configs, trained
weights, and compilation settings are all saved.
ggml_functional_model — input/output node graphs (pure R
lists, no ggml pointers) and trained node_weights are saved.
model <- ggml_model_sequential() |>
ggml_layer_dense(16L, activation = "relu", input_shape = 4L) |>
ggml_layer_dense(2L, activation = "softmax")
model <- ggml_compile(model, optimizer = "adam",
loss = "categorical_crossentropy")
x <- matrix(runif(64 * 4), 64, 4)
y <- matrix(c(rep(c(1,0), 32), rep(c(0,1), 32)), 64, 2)
model <- ggml_fit(model, x, y, epochs = 1L, batch_size = 32L, verbose = 0L)
tmp <- tempfile(fileext = ".rds")
ggml_save_model(model, tmp)
model2 <- ggml_load_model(tmp)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.