| ggml_save_weights | R Documentation |
Saves the trained weights of a sequential model to an RDS file. The file includes both weights and architecture metadata for validation when loading.
ggml_save_weights(model, path)
model |
A trained ggml_sequential_model |
path |
File path to save weights (typically with .rds extension) |
The model (invisibly).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.