| ggml_set | R Documentation |
Copies tensor b into tensor a at a specified offset. This allows writing to a portion of a tensor.
ggml_set(ctx, a, b, nb1, nb2, nb3, offset)
ctx |
GGML context |
a |
Destination tensor |
b |
Source tensor (data to copy) |
nb1 |
Stride for dimension 1 (in bytes) |
nb2 |
Stride for dimension 2 (in bytes) |
nb3 |
Stride for dimension 3 (in bytes) |
offset |
Byte offset in destination tensor |
Tensor representing the set operation
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.