Copies tensor b into tensor a at a specified offset. This allows writing to a portion of a tensor.
ggml_set(ctx, a, b, nb1, nb2, nb3, offset)Tensor representing the set operation
GGML context
Destination tensor
Source tensor (data to copy)
Stride for dimension 1 (in bytes)
Stride for dimension 2 (in bytes)
Stride for dimension 3 (in bytes)
Byte offset in destination tensor