| ggml_set_param | R Documentation |
Marks a tensor as a trainable parameter for backpropagation. The optimizer will compute gradients for this tensor during training.
ggml_set_param(tensor)
tensor |
Tensor pointer |
The tensor (for chaining)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.