Learn R Programming

ggmlR (version 0.6.1)

ggml_set_param: Set Tensor as Trainable Parameter

Description

Marks a tensor as a trainable parameter for backpropagation. The optimizer will compute gradients for this tensor during training.

Usage

ggml_set_param(tensor)

Value

The tensor (for chaining)

Arguments

tensor

Tensor pointer