| ggml_soft_max_ext_back_inplace | R Documentation |
Creates a graph node for the backward pass of extended softmax, modifying in place.
ggml_soft_max_ext_back_inplace(ctx, a, b, scale = 1, max_bias = 0)
ctx |
GGML context |
a |
Gradient tensor from upstream |
b |
Softmax output from forward pass |
scale |
Scaling factor used in forward pass |
max_bias |
Maximum ALiBi bias used in forward pass |
View of input tensor with gradient computed in place
Other softmax:
ggml_soft_max_ext_inplace()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.