Creates a graph node for the backward pass of extended softmax, modifying in place.
ggml_soft_max_ext_back_inplace(ctx, a, b, scale = 1, max_bias = 0)View of input tensor with gradient computed in place
GGML context
Gradient tensor from upstream
Softmax output from forward pass
Scaling factor used in forward pass
Maximum ALiBi bias used in forward pass
Other softmax:
ggml_soft_max_ext_inplace()