A device group with more than one device and peer copy/generic memory
features is the prerequisite for true GPU-to-GPU transfers routed over NVLink
(or PCIe peer-to-peer) through a single device-group logical device — as
opposed to sharing memory as an opaque fd between independent devices, which
the driver may route through host memory.
This is a diagnostic only: it does not create any long-lived device group.
On a machine with a single GPU it reports zero multi-device groups. Device
groups for compute are effectively an NVIDIA feature; AMD/RADV typically
reports only single-device groups.