Learn R Programming

ggmlR (version 0.8.1)

gguf_tensor_info: Get Tensor Info

Description

Returns name, shape, type, and size in bytes for a single tensor.

Usage

gguf_tensor_info(x, name)

Value

A list with elements name, shape, type,

size_bytes.

Arguments

x

A gguf object.

name

Tensor name (character).

Details

When the file was opened with meta_only = TRUE, the per-dimension shape is NA (the public GGUF API does not expose tensor dimensions without allocating tensors); name, type and size_bytes are still returned.