View source: R/nn_functional.R
| nn_build_functional_node | R Documentation |
Build a single ggml tensor for one functional node
nn_build_functional_node(
node,
built_tensors,
built_shapes,
ctx_weights,
ctx_compute,
batch_size,
training = FALSE,
reuse_weights = NULL
)
reuse_weights |
Named list of pre-allocated weight tensors to reuse (for shared layers – second+ application of a named layer). When not NULL the function uses these tensors instead of allocating new ones. |
A ggml_tensor produced by building the given functional graph node.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.