Learn R Programming

ggmlR (version 0.6.1)

nn_build_functional_node: Build a single ggml tensor for one functional node

Description

Build a single ggml tensor for one functional node

Usage

nn_build_functional_node(
  node,
  built_tensors,
  built_shapes,
  ctx_weights,
  ctx_compute,
  batch_size,
  training = FALSE,
  reuse_weights = NULL
)

Arguments

reuse_weights

Named list of pre-allocated weight tensors to reuse (for shared layers -- second+ application of a named layer). When not NULL the function uses these tensors instead of allocating new ones.