Build a single ggml tensor for one functional node
nn_build_functional_node(
node,
built_tensors,
built_shapes,
ctx_weights,
ctx_compute,
batch_size,
training = FALSE,
reuse_weights = NULL
)Named list of pre-allocated weight tensors to reuse (for shared layers -- second+ application of a named layer). When not NULL the function uses these tensors instead of allocating new ones.