View source: R/nn_functional.R
| nn_functional_output_shape | R Documentation |
Infer output shape of a functional node given its parent shapes
nn_functional_output_shape(node, parent_shapes)
An integer vector with the inferred output shape (excluding the batch dimension).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.