Learn R Programming

ggmlR (version 0.6.1)

nn_functional_output_shape: Infer output shape of a functional node given its parent shapes

Description

Infer output shape of a functional node given its parent shapes

Usage

nn_functional_output_shape(node, parent_shapes)

Arguments